pub enum RootError {
ZeroDerivative {
x_cur: f64,
},
IteratedToNaN {
x_new: f64,
},
IterationLimit {
last_x: f64,
},
}Expand description
Root finding error conditions.
To help with diagnostics, these errors typically return the last relevant
x position.
Variants
ZeroDerivative
Derivative went to zero for method that depends on it to determine next step.
IteratedToNaN
The solver computed a NaN for its next step x-value.
IterationLimit
Iteration limit was reached.